@@ -284,6 +284,10 @@ class QACaller(CallerBase):
         for sq_data in resp["data"]:
             sq_data['id'] = str(sq_data['id'])
             sq_data['category_id'] = str(sq_data['category_id'])
+            for answer in sq_data['answers']:
+                answer['id'] = str(answer['id'])
+                answer['sq_id'] = str(answer['sq_id'])
+
         return resp["data"]
 
     def lq_list(self, qa_id: str):
@@ -474,7 +478,7 @@ class QACaller(CallerBase):
             url = url + "?keyword=" + keyword.strip()
         if page is not None and size is not None:
             url = url + "&page_size=" + size + "&page_index=" + page
-        resp = requests.get(url,headers=self.header, json={}).json()
+        resp = requests.get(url, headers=self.header, json={}).json()
         code = int(resp["code"])
         msg = str(resp["message"])
         if code != 0:
@@ -490,8 +494,45 @@ class QACaller(CallerBase):
         ## 问题调更新接口，语料删除重插
         question_id = data.get('id')
         data["id"] = int(data["id"])
-        data["category_id"] = int(data["category_id"])
+        if( "tag_id_list" not in data.keys()):
+            data.update({"tag_id_list": []})
+        if("category_id" in data.keys()):
+             data["category_id"] = int(data["category_id"])
+        else:
+             data.update({"category_id": -1})
         requests.put(self.upload_faq_json_sq_url, headers=self.header, json=data).json()
+        if("lq" in data.keys()):
+            lq_request_list= data.get("lq")
+            if(len(lq_request_list) > 0):
+               lq_list = self.query_corpus(question_id)
+               lq_id_list = []
+               for lq in lq_list:
+                  lq_id_list.append({"id":lq['id']})
+               self.delete_corpus_list(question_id,lq_id_list)
+               lq_insert_list=[]
+               for lq in lq_request_list:
+                   lq_insert_list.append({"lq":lq})
+               self.add_corpus_list(question_id,lq_insert_list)
+        if("answers" in data.keys()):
+             answer_request_list = data.get("answers")
+             if(len(answer_request_list) > 0):
+               ans_resp = requests.get(self.upload_faq_json_sq_url + "/" + str(question_id)+"?field=answer", headers=self.header, json={}).json()
+               code = int(ans_resp["code"])
+               msg = str(ans_resp["message"])
+               if code != 0:
+                 raise BfEngineException(code=code, msg=msg)
+               for ans in ans_resp['data']['answers']:
+                   self.delete_answer(ans['id'])
+               for insert_answer in answer_request_list:
+                   insert_data = {
+                       "answer":insert_answer,
+                       "start_time":"",
+                       "end_time":"",
+                       "sq_id":int(question_id),
+                       "tag_id_list": [],
+                       "related_sq_id_list":[]
+                   }
+                   self.add_answer(insert_data)
         return question_id
 
     def delete_question(self, question_id):
