@@ -3,7 +3,7 @@ import copy
 import os
 import traceback
 import qrcode
-import qrcode_terminal
+# import qrcode_terminal
 import uuid
 from .. import util
 
@@ -235,7 +235,7 @@ class DialogueManager(Module):
         super().__init__(app_id, 'dm', set)
         self.app_id = app_id
         self.module_call_url = '{}/{}'.format(Config.base_url, Config.robot_url)
-        self.chat_url = '{}/{}?appId={}'.format("http://172.16.103.106", Config.chat_url,app_id)
+        self.chat_url = '{}/{}?appId={}'.format(Config.base_url, Config.chat_url,app_id)
         self.caller = DialogueManagerCaller(app_id)
         tmp_dir = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
         self.default_dm_config_path = tmp_dir + "/data/default_dm.json"
@@ -387,7 +387,7 @@ class DialogueManager(Module):
         workflow.append(backfill_phase)
 
         return config
-    def chat(self,filePath:str=None):
+    def qrcode(self,filePath:str=None):
         if filePath:
             qr = qrcode.QRCode(
                 version=None,
@@ -400,7 +400,8 @@ class DialogueManager(Module):
             img = qr.make_image()
             img.save(filePath)
         else:
-            qrcode_terminal.draw(self.chat_url)
+            return
+            # qrcode_terminal.draw(self.chat_url)
     def query(self, msg):
         try:
             answer = self.caller.call(msg)
