@@ -47,7 +47,6 @@ class IntentAnswering(Module):
                     self._train(group_id=group_id)
             elif intent_path:
                 return
-            self.intentCaller.open_default_intent()
         except BfEngineException as bfe:
             log.error(bfe)
             return False
@@ -56,6 +55,17 @@ class IntentAnswering(Module):
             log.error(e)
             return False
         return True
+    def open_inner_intents(self):
+        self.intentCaller.open_default_intent()
+
+    def close_inner_intents(self):
+        self.intentCaller.close_default_intent()
+
+    def close_intent_group(self,group_id:str=None):
+        self.intentCaller.close_intent_group(group_id=group_id)
+
+    def open_intent_group(self, group_id: str = None):
+        self.intentCaller.open_intent_group(group_id=group_id)
     def predict(self, text: str,online: bool=False) -> Answer:
         data = self.intentCaller.predict(text,online)
         if not data:
